@@ -419,39 +419,6 @@ class Connection_:
                     assert middle == Connection("jumpuser2@jumphost2:872")
                     assert outermost == Connection("jumpuser@jumphost:373")
 
-                def wildcards_do_not_trigger_recursion(self):
-                    # When #1850 is present, this will RecursionError.
-                    conf = self._runtime_config(basename="proxyjump_recursive")
-                    cxn = Connection("runtime.tld", config=conf)
-                    assert cxn.gateway == Connection("bastion.tld")
-                    assert cxn.gateway.gateway is None
-
-                def multihop_plus_wildcards_still_no_recursion(self):
-                    conf = self._runtime_config(
-                        basename="proxyjump_multi_recursive"
-                    )
-                    cxn = Connection("runtime.tld", config=conf)
-                    outer = cxn.gateway
-                    inner = cxn.gateway.gateway
-                    assert outer == Connection("bastion1.tld")
-                    assert inner == Connection("bastion2.tld")
-                    assert inner.gateway is None
-
-                def gateway_Connections_get_parent_connection_configs(self):
-                    conf = self._runtime_config(
-                        basename="proxyjump",
-                        overrides={"some_random_option": "a-value"},
-                    )
-                    cxn = Connection("runtime", config=conf)
-                    # Sanity
-                    assert cxn.config is conf
-                    assert cxn.gateway == self._expected_gw
-                    # Real check
-                    assert cxn.gateway.config.some_random_option == "a-value"
-                    # Prove copy not reference
-                    # TODO: would we ever WANT a reference? can't imagine...
-                    assert cxn.gateway.config is not conf
-
             class connect_timeout:
                 def wins_over_default(self):
                     assert self._runtime_cxn().connect_timeout == 15
@@ -500,6 +467,17 @@ class Connection_:
                 )
                 assert cxn.connect_kwargs == {"origin": "kwarg"}
 
+        class inline_ssh_env:
+            def defaults_to_config_value(self):
+                assert Connection("host").inline_ssh_env is False
+                config = Config({"inline_ssh_env": True})
+                assert Connection("host", config=config).inline_ssh_env is True
+
+            def may_be_given(self):
+                assert Connection("host").inline_ssh_env is False
+                cxn = Connection("host", inline_ssh_env=True)
+                assert cxn.inline_ssh_env is True
+
     class string_representation:
         "string representations"
 
@@ -852,6 +830,13 @@ class Connection_:
             c.run("command")
             assert c.open.called
 
+        @patch(remote_path)
+        def passes_inline_env_to_Remote(self, Remote, client):
+            Connection("host").run("command")
+            assert Remote.call_args[1]["inline_env"] is False
+            Connection("host", inline_ssh_env=True).run("command")
+            assert Remote.call_args[1]["inline_env"] is True
+
         @patch(remote_path)
         def calls_Remote_run_with_command_and_kwargs_and_returns_its_result(
             self, Remote, client
@@ -866,7 +851,7 @@ class Connection_:
             # .assert_called_with()) stopped working, apparently triggered by
             # our code...somehow...after commit (roughly) 80906c7.
             # And yet, .call_args_list and its brethren work fine. Wha?
-            Remote.assert_any_call(c)
+            Remote.assert_any_call(c, inline_env=False)
             remote.run.assert_has_calls(
                 [call("command"), call("command", warn=True, hide="stderr")]
             )
@@ -890,6 +875,13 @@ class Connection_:
             c.sudo("command")
             assert c.open.called
 
+        @patch(remote_path)
+        def passes_inline_env_to_Remote(self, Remote, client):
+            Connection("host").sudo("command")
+            assert Remote.call_args[1]["inline_env"] is False
+            Connection("host", inline_ssh_env=True).sudo("command")
+            assert Remote.call_args[1]["inline_env"] is True
+
         @patch(remote_path)
         def basic_invocation(self, Remote, client):
             # Technically duplicates Invoke-level tests, but ensures things
@@ -901,7 +893,10 @@ class Connection_:
             # None despite call_args_list being populated. WTF. (Also,
             # Remote.return_value is two different Mocks now, despite Remote's
             # own Mock having the same ID here and in code under test. WTF!!)
-            expected = [call(cxn), call().run(cmd, watchers=ANY)]
+            expected = [
+                call(cxn, inline_env=False),
+                call().run(cmd, watchers=ANY),
+            ]
             assert Remote.mock_calls == expected
             # NOTE: we used to have a "sudo return value is literally the same
             # return value from Remote.run()" sanity check here, which is
